import { HttpClient, MaybeContext, BuildRESTFunction } from '@wix/sdk-types';
import { TokenOptions, RawHttpResponse, TokenInfoOptions, TokenInfoResponse } from './index.typings.mjs';
export { ActionEvent, AuthorizeRequest, DeviceCodeRequest, DeviceCodeResponse, DeviceVerifyRequest, DeviceVerifyResponse, DeviceVerifyV2Request, DeviceVerifyV2Response, DomainEvent, DomainEventBodyOneOf, Empty, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, HeadersEntry, InvalidateUserCodeRequest, InvalidateUserCodeResponse, PathParametersEntry, QueryParametersEntry, RawHttpRequest, RefreshToken, RestoreInfo, RevokeRefreshTokenRequest, RevokeRefreshTokenResponse, SubjectType } from './index.typings.mjs';

declare function token$1(httpClient: HttpClient): TokenSignature;
interface TokenSignature {
    /**
     * Creates an access token.
     *
     *
     * The endpoint accepts raw HTTP requests. You must pass the request's body
     * parameters formatted as bytes in the raw HTTP request's `body` field,
     * following this template:
     * `{"grantType": "client_credentials", "client_id": "<APP_ID>", "client_secret": "<APP_SECRET_KEY>", "instance_id": "<INSTANCE_ID>"}`.
     *
     * When the call succeeds, Wix returns `{"statusCode": 200}` and the created access
     * token in the `body` field of the raw HTTP response.
     *
     * In case the call fails, Wix returns the relevant `4XX` error code in the raw
     * HTTP response's `statusCode` field and details
     * about the error in `body`. Error details follow the
     * [conventions of the Internet Engineering Task Force (IETF)](https://datatracker.ietf.org/doc/html/rfc6749#appendix-A.7).
     */
    (options?: TokenOptions | undefined): Promise<RawHttpResponse>;
}
declare function tokenInfo$1(httpClient: HttpClient): TokenInfoSignature;
interface TokenInfoSignature {
    /**
     * Token Introspection Endpoint.
     */
    (options?: TokenInfoOptions | undefined): Promise<TokenInfoResponse>;
}

declare const token: MaybeContext<BuildRESTFunction<typeof token$1> & typeof token$1>;
declare const tokenInfo: MaybeContext<BuildRESTFunction<typeof tokenInfo$1> & typeof tokenInfo$1>;

export { RawHttpResponse, TokenInfoOptions, TokenInfoResponse, TokenOptions, token, tokenInfo };
